@@ -7,13 +7,12 @@ they all import from each other via this __init__ file using
 """
 
 from ..rust_module.ultima_pyengine import NoDataError, OtherError
-from .agg_request import AggRequest, aggregation_ops
 from .dataset import DS, DataSet, FRTBDataSet
-from .execute import execute_agg
+from .requests import AggRequest, ComputeRequest, aggregation_ops
 
 __all__ = [
-    "execute_agg",
     "AggRequest",
+    "ComputeRequest",
     "aggregation_ops",
     "FRTBDataSet",
     "DataSet",
